@@ -63,6 +63,7 @@ describe 'gnocchi::api' do
       is_expected.to contain_gnocchi_config('api/middlewares').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_oslo__middleware('gnocchi_config').with(
         :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+        :max_request_body_size        => '<SERVICE DEFAULT>',
       )
     end
 
@@ -165,6 +166,16 @@ describe 'gnocchi::api' do
       )}
     end
 
+    context 'with max_request_body_size' do
+      before do
+        params.merge!({:max_request_body_size => '102400' })
+      end
+
+      it { is_expected.to contain_oslo__middleware('gnocchi_config').with(
+        :max_request_body_size => '102400',
+      )}
+    end
+
   end
 
   on_supported_os({
@@ -180,11 +191,7 @@ describe 'gnocchi::api' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian' then
-            package_name = 'gnocchi-api'
-          else
-            package_name = 'python-gnocchi'
-          end
+          package_name = 'gnocchi-api'
         when 'RedHat'
           package_name = 'gnocchi-api'
         end
